# frozen_string_literal: true

EurekaRuby.configure do |config|
  # Required
  config.eureka_url      = ENV['EUREKA_URL']
  config.app_id          = ENV['EUREKA_MS_APP_ID']
  config.host_name       = ENV.fetch('EUREKA_MS_HOST_NAME', ENV['HOSTNAME'])
  config.ip_addr         = ENV.fetch('EUREKA_MS_IP_ADDR', ENV['HOSTNAME'])
  config.info_response   = { "author" => "Tumayun", "language" => "Ruby" }

  # Optional
  config.port            = ENV.fetch('EUREKA_MS_PORT', ENV['PORT']).to_i  # default 3000
  config.scheme          = ENV.fetch('EUREKA_MS_SCHEMA', 'http')          # default http
  config.health_path     = ENV.fetch('EUREKA_MS_HEALTH_PATH', '/health')  # default /health
  config.health_response = 'OK'                                           # default OK
  config.health_headers  = { "Content-Type" => "text/plain" }             # default
  config.info_path       = ENV.fetch('EUREKA_MS_INFO_PATH', '/info')      # default /info
end

if ENV['EUREKA']
  # Register Instance
  EurekaRuby.executor.run(:register)

  # Keep Living
  Thread.new do
    loop do
      response = EurekaRuby.executor.run(:send_heartbeat)
      next if [200, 204].include? response.status

      error_text = "发送心跳到 Eureka 失败: status: #{response.status} body: #{response.body.to_s}"

      EurekaRuby.executor.run(:register) if response.status == 404
    rescue => ex
      error_text = "发送心跳到 Eureka 失败: #{ex.message}\n#{ex.backtrace.join("\n")}"
    ensure
      if error_text
        Rails.logger.error(error_text)
        NewRelic::Agent.notice_error(error_text) if defined?(NewRelic)
      end

      sleep ENV.fetch('EUREKA_HEARTBEAT_PERIOD', 5).to_i
    end
  end
end
